# Grid 布局

## 基础布局

:::snippet 通过 `j-row` 和 `j-col` 组件，并通过 `j-col` 组件的 `span` 属性自由地组合布局。

```html
<template>
  <div class="j-demo--grid">
    <j-row>
      <j-col :span="24">
        <div>100%</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :key="index" v-for="index in 2" :span="12">
        <div>50%</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :key="index" v-for="index in 3" :span="8">
        <div>33.3%</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :key="index" v-for="index in 4" :span="6">
        <div>25%</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :key="index" v-for="index in 6" :span="4">
        <div>16.6%</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :key="index" v-for="index in 8" :span="3">
        <div>8.3%</div>
      </j-col>
    </j-row>
  </div>
</template>

<style>
  .j-demo--grid .j-row {
    border-top: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-row:last-child {
    border-bottom: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col {
    color: #969696;
    background: #f5f7fb;
    border-left: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col:last-child {
    border-right: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col > div {
    padding: 6px;
  }
</style>
```

:::

## Flex 的布局

:::snippet `j-row` 设置 `type` 属性值：`flex` ,设置 `justify` 和 `align` 指定对其格式。

```html
<template>
  <div class="j-demo--grid">
    <j-row type="flex" justify="start">
      <j-col :key="index" v-for="index in 3" :span="4">
        <div>span-4</div>
      </j-col>
    </j-row>
    <j-row type="flex" justify="center">
      <j-col :key="index" v-for="index in 3" :span="4">
        <div>span-4</div>
      </j-col>
    </j-row>
    <j-row type="flex" justify="end">
      <j-col :key="index" v-for="index in 3" :span="4">
        <div>span-4</div>
      </j-col>
    </j-row>
    <j-row type="flex" justify="space-around">
      <j-col class="j-demo-layout--right-boder" :key="index" v-for="index in 3" :span="4">
        <div>span-4</div>
      </j-col>
    </j-row>
    </j-row>
    <j-row type="flex" justify="space-between">
      <j-col class="j-demo-layout--right-boder" :key="index" v-for="index in 3" :span="4">
        <div>span-4</div>
      </j-col>
    </j-row>
  </div>
</template>

<style>
  .j-demo--grid .j-row {
    border-top: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-row:last-child {
    border-bottom: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col {
    color: #969696;
    background: #f5f7fb;
    border-left: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col:last-child {
    border-right: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col > div {
    padding: 6px;
  }
  .j-demo-layout--right-boder{
     border-right: 1px solid #d2d2d2;
  }
</style>
```

:::

## Offset 偏移

:::snippet `j-col` 设置 `offset` 属性指定偏移占位。

```html
<template>
  <div class="j-demo--grid">
    <j-row>
      <j-col class="j-demo-layout--right-boder" :span="6">
        <div>offset-6</div>
      </j-col>
      <j-col :span="6" :offset="6">
        <div>offset-6</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col class="j-demo-layout--right-boder" :span="6" :offset="6">
        <div>offset-6</div>
      </j-col>
      <j-col :span="6" :offset="6">
        <div>offset-6</div>
      </j-col>
    </j-row>
    <j-row>
      <j-col :span="12" :offset="6">
        <div>offset-6</div>
      </j-col>
    </j-row>
  </div>
</template>

<style>
  .j-demo--grid .j-row {
    border-top: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-row:last-child {
    border-bottom: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col {
    color: #969696;
    background: #f5f7fb;
    border-left: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col:last-child {
    border-right: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col > div {
    padding: 6px;
  }
  .j-demo-layout--right-boder {
    border-right: 1px solid #d2d2d2;
  }
</style>
```

:::

## 响应布局

:::snippet 参照了 `Bootstrap` 响应式设计，预设尺寸：`xs`、`sm`、`md`、`lg` 和 `xl`。

```html
<template>
  <div class="j-demo--grid">
    <j-row>
      <j-col :xs="8" :sm="6" :md="4" :lg="3" :xl="5" :span="8">
        <div>content</div>
      </j-col>
      <j-col :xs="8" :sm="12" :md="4" :lg="3" :xl="5" :span="8">
        <div>content</div>
      </j-col>
      <j-col :xs="8" :sm="6" :md="16" :lg="18" :xl="14" :span="8">
        <div>content</div>
      </j-col>
    </j-row>
  </div>
</template>

<style>
  .j-demo--grid .j-row {
    border-top: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-row:last-child {
    border-bottom: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col {
    color: #969696;
    background: #f5f7fb;
    border-left: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col:last-child {
    border-right: 1px solid #d2d2d2;
  }
  .j-demo--grid .j-col > div {
    padding: 6px;
  }
</style>
```

:::

## JRow Attributes

| 参数    | 说明                                  | 类型   | 可选值                                      | 默认值 |
| ------- | ------------------------------------- | ------ | ------------------------------------------- | ------ |
| gutter  | 栅格间隔                              | number | —                                           | 0      |
| type    | 布局模式，可选 flex，现代浏览器下有效 | string | —                                           | —      |
| justify | flex 布局下的水平排列方式             | string | start/end/center/space-around/space-between | start  |
| align   | flex 布局下的垂直排列方式             | string | top/middle/bottom                           | top    |
| tag     | 自定义元素标签                        | string | \*                                          | div    |

## JCol Attributes

| 参数   | 说明                                   | 类型                                        | 可选值 | 默认值 |
| ------ | -------------------------------------- | ------------------------------------------- | ------ | ------ |
| span   | 栅格占据的列数                         | number                                      | —      | 24     |
| offset | 栅格左侧的间隔格数                     | number                                      | —      | 0      |
| push   | 栅格向右移动格数                       | number                                      | —      | 0      |
| pull   | 栅格向左移动格数                       | number                                      | —      | 0      |
| xs     | `<768px` 响应式栅格数或者栅格属性对象  | number/object (例如： {span: 4, offset: 4}) | —      | —      |
| sm     | `≥768px` 响应式栅格数或者栅格属性对象  | number/object (例如： {span: 4, offset: 4}) | —      | —      |
| md     | `≥992px` 响应式栅格数或者栅格属性对象  | number/object (例如： {span: 4, offset: 4}) | —      | —      |
| lg     | `≥1200px` 响应式栅格数或者栅格属性对象 | number/object (例如： {span: 4, offset: 4}) | —      | —      |
| xl     | `≥1920px` 响应式栅格数或者栅格属性对象 | number/object (例如： {span: 4, offset: 4}) | —      | —      |
| tag    | 自定义元素标签                         | string                                      | \*     | div    |
